/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.internal.Header");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dijit.Menu");
dojo.require("dijit.Toolbar");
dojo.require("dijit.form.Button");
dojo.require("dijit.Dialog");
dojo.require("net.jazz.ajax.ui.PageList");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.rational.report.web.core.app.internal.Login");
dojo.require("com.ibm.rational.report.web.core.app.internal.Logout");
dojo.require("com.ibm.rational.report.web.core.app.internal.Util");
dojo.require("com.ibm.team.repository.web.client.init.InitializationData");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.ui.internal.ProjectSelector");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal", "Messages");

var InternalMessages		= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal", "Messages");
var isGuest					= com.ibm.team.repository.web.client.session.isGuest;
var InitializationData		= com.ibm.team.repository.web.client.init.InitializationData;
var ServiceResponseHandler	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var ProjectSelector			= com.ibm.team.repository.web.ui.internal.ProjectSelector;
var Util					= com.ibm.rational.report.web.core.app.internal.Util;
var X_AUTH_MSG				= "X-com-ibm-team-repository-web-auth-msg";

/**
 * Displays the banner, menu bar and links.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.internal.Header",
	[dijit._Widget, dijit._Templated], {

	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/templates/Header.html"),
	
	showLoginPanel: false,
	
	/**
	 * Fill in the dynamic elements of the header nav.
	 */
	postCreate: function() {
		if (this.showLoginPanel) {
			if (this._isInitDataLoaded()) {
				this._showPanel();
			} else {
				this._showPanelNoRepo();
			}
		}
		
		this.showProjectAreaSelector();
	},
	
	showProjectAreaSelector: function() {
	},

	getLoginWidget: function() {
		return new com.ibm.rational.report.web.core.app.internal.Login();
	},
		
	getLogoutWidget: function(args) {
		return new com.ibm.rational.report.web.core.app.internal.Logout(args);
	},
	
	_createPageList: function() {
		var args = this.suppressedPages ?
			{suppressedPages: this.suppressedPages} : {};
		var pageList = new net.jazz.ajax.ui.PageList(args);
		this.pageListContainer.appendChild(pageList.domNode);
	},
	
	_showPanel: function() {
		if (isGuest()) {
			this._showLoginPanel();
		} else {
			this._showLogoutPanel();
		}
	},
	
	_showPanelNoRepo: function () {
		var bindArgs = {
	        url: net.jazz.ajax._contextRoot + "/auth/whoami",
	        content: { },
			handleAs: "json",
			headers: { },
			handle: dojo.hitch(this, function(response, ioArgs){
				if (response instanceof Error) {
					var errorObj = {
						status: ioArgs.xhr.status
					};
					// format detailed message (unescape URI-encoding formatting, remove leading dashes, and trim whitespace)
					errorObj.message= dojo.trim(unescape(ioArgs.xhr.statusText).replace(/\+/g, " ").replace(/^(-*)/g, ""));
					serviceResponseHandler.doErrorCallback(errorObj);
				}
				else if (ioArgs.xhr.getResponseHeader(X_AUTH_MSG) == null) {
					this._showLoginPanel();
				}
				else {
					this._showLogoutPanel(ioArgs.xhr.getResponseHeader(X_AUTH_MSG));
				}
	        })
	    };
	    dojo.xhrGet(bindArgs);
	},

	_showLoginPanel: function() {
		this.loginPanelContainer.appendChild(this.getLoginWidget().domNode);
	},
	
	_showLogoutPanel: function(loggedInUser) {
		this.loginPanelContainer.appendChild(this.getLogoutWidget({ "loggedInUser": loggedInUser}).domNode);
	},
	
	_isInitDataLoaded: function() {
		if (InitializationData.get("com.ibm.team.repository.service.currentContributorInitializer")) {
			return true;
		}
		return false;
	}

});

})();
